@@ -4,9 +4,9 @@ use Parse::Stallion;
 use Time::Local;
 
 my %rule;
-$rule{start_date} = { 
-  and => ['parsed_date', 'end_of_string'],
-  evaluation => sub {
+$rule{start_date} =
+  A('parsed_date', 'end_of_string',
+   E(sub {
     my $seconds_since_epoch = $_[0]->{parsed_date};
     my ($seconds, $minutes, $hour, $mday, $month, $year) =
      gmtime($seconds_since_epoch);
@@ -17,63 +17,54 @@ $rule{start_date} = {
     if ($minutes < 10) { $minutes = '0'.$minutes;};
     if ($hour < 10) { $hour = '0'.$hour;};
     return (1900+$year).$month.$mday.$hour.$minutes.$seconds;
-  }
-};
-$rule{parsed_date} = { 
-  or => ['date', 'date_operation'],
-};
-$rule{date_operation} = { 
-  or => ['add_time', 'subtract_time'],
-};
-$rule{add_time} = { 
-  and => ['date', 'plus', 'time'],
-  evaluation => sub {return $_[0]->{date} + $_[0]->{time}}
-};
-$rule{subtract_time} = { 
-  and => ['date', 'minus', 'time'],
-  evaluation => sub {
-   return $_[0]->{date} - $_[0]->{time}}
-};
-$rule{date} = { 
-  or => ['standard_date', 'special_date']
-};
-$rule{end_of_string} = {
-  regex_match => qr/\z/,
-};
-$rule{plus} = { 
-  regex_match => qr/\s*\+\s*/,
-};
-$rule{minus} = { 
-  regex_match => qr/\s*\-\s*/,
-};
-$rule{standard_date} = { 
-  regex_match => qr(\d+\/\d+\/\d+),
-  evaluation => sub {my $date = $_[0];
+  })
+);
+$rule{parsed_date} =
+  O('date', 'date_operation');
+$rule{date_operation} =
+  O('add_time', 'subtract_time');
+$rule{add_time} =
+  A('date', 'plus', 'time',
+   E(sub {return $_[0]->{date} + $_[0]->{time}}))
+;
+$rule{subtract_time} =
+  A('date', 'minus', 'time',
+   E(sub {
+   return $_[0]->{date} - $_[0]->{time}})
+);
+$rule{date} =
+  O('standard_date', 'special_date');
+$rule{end_of_string} = qr/\z/;
+$rule{plus} = qr/\s*\+\s*/;
+$rule{minus} = qr/\s*\-\s*/;
+$rule{standard_date} =
+  L(qr(\d+\/\d+\/\d+),
+   E(sub {my $date = $_[0];
     $date =~ /(\d+)\/(\d+)\/(\d+)/;
     my $month = $1 -1;
     my $mday = $2;
     my $year = $3;
     return timegm(0,0,0,$mday, $month, $year);
-  },
-};
-$rule{special_date} = { 
-  regex_match => qr/now/i,
-  evaluation => sub {return time;},
-};
-$rule{time} = { 
-  or => ['just_time', 'just_time_plus_list', 'just_time_minus_list']
-};
-$rule{just_time_plus_list} = { 
-  and => ['just_time', 'plus', 'time'],
-  evaluation => sub {return $_[0]->{just_time} + $_[0]->{time}}
-};
-$rule{just_time_minus_list} = { 
-  and => ['just_time', 'minus', 'time'],
-  evaluation => sub {return $_[0]->{just_time} - $_[2]->{time}}
-};
-$rule{just_time} = { 
-  regex_match => qr(\d+\s*[hdms])i,
-  evaluation => sub {
+  })
+);
+$rule{special_date} =
+  L(qr/now/i,
+   E(sub {return time;})
+);
+$rule{time} =
+  O('just_time', 'just_time_plus_list', 'just_time_minus_list'
+);
+$rule{just_time_plus_list} =
+  A('just_time', 'plus', 'time',
+   E(sub {return $_[0]->{just_time} + $_[0]->{time}})
+);
+$rule{just_time_minus_list} =
+  A('just_time', 'minus', 'time',
+   E(sub {return $_[0]->{just_time} - $_[2]->{time}})
+);
+$rule{just_time} = L(
+  qr(\d+\s*[hdms])i,
+  E(sub {
     my $to_match = $_[0];
     $to_match =~ /(\d+)\s*([hdms])/i;
     my $number = $1;
@@ -90,8 +81,8 @@ $rule{just_time} = {
     if (lc $unit eq 'm') {
       return $1 * 60;
     }
-  }
-};
+  })
+);
 
 my $date_parser = new Parse::Stallion({
   rules_to_set_up_hash => \%rule,
